import { resolveDirective as _resolveDirective, Fragment as _Fragment, createVNode as _createVNode, mergeProps as _mergeProps } from "vue";
// Styles
import "./VDatePicker.css";

// Components
import { makeVDatePickerControlsProps, VDatePickerControls } from "./VDatePickerControls.mjs";
import { makeVDatePickerHeaderProps, VDatePickerHeader } from "./VDatePickerHeader.mjs";
import { makeVDatePickerMonthProps, VDatePickerMonth } from "./VDatePickerMonth.mjs";
import { makeVDatePickerYearsProps, VDatePickerYears } from "./VDatePickerYears.mjs";
import { VBtn } from "../../components/VBtn/index.mjs";
import { VTextField } from "../../components/VTextField/index.mjs";
import { dateEmits, makeDateProps } from "../VDateInput/composables.mjs";
import { makeVPickerProps, VPicker } from "../VPicker/VPicker.mjs"; // Composables
import { createDatePicker } from "./composables.mjs";
import { useLocale } from "../../composables/locale.mjs";
import { useProxiedModel } from "../../composables/proxiedModel.mjs";
import { makeTransitionProps, MaybeTransition } from "../../composables/transition.mjs";
import { useDate } from "../date/index.mjs"; // Utilities
import { computed, ref, watch } from 'vue';
import { genericComponent, propsFactory, useRender } from "../../util/index.mjs";
export const makeVDatePickerProps = propsFactory({
  cancelText: {
    type: String,
    default: '$vuetify.datePicker.cancel'
  },
  okText: {
    type: String,
    default: '$vuetify.datePicker.ok'
  },
  inputText: {
    type: String,
    default: '$vuetify.datePicker.input.placeholder'
  },
  hideActions: Boolean,
  ...makeDateProps(),
  ...makeTransitionProps({
    transition: 'fade'
  }),
  ...makeVDatePickerControlsProps(),
  ...makeVDatePickerHeaderProps(),
  ...makeVDatePickerMonthProps(),
  ...makeVDatePickerYearsProps(),
  ...makeVPickerProps({
    title: '$vuetify.datePicker.title'
  })
}, 'VDatePicker');
export const VDatePicker = genericComponent()({
  name: 'VDatePicker',
  props: makeVDatePickerProps(),
  emits: {
    'click:cancel': () => true,
    'click:save': () => true,
    ...dateEmits
  },
  setup(props, _ref) {
    let {
      emit
    } = _ref;
    const adapter = useDate();
    const {
      t
    } = useLocale();
    createDatePicker(props);
    const displayDate = useProxiedModel(props, 'displayDate', props.displayDate);
    const inputMode = useProxiedModel(props, 'inputMode', props.inputMode);
    const viewMode = useProxiedModel(props, 'viewMode', props.viewMode);
    const inputModel = ref(props.modelValue?.length ? adapter.format(props.modelValue[0], 'keyboardDate') : '');
    const selected = ref(props.modelValue ?? []);
    const title = computed(() => t(props.title));
    watch(inputModel, () => {
      const {
        isValid,
        date
      } = adapter;
      selected.value = isValid(inputModel.value) ? [date(inputModel.value)] : [];
    });
    watch(selected, () => {
      if (props.hideActions) {
        emit('update:modelValue', selected.value);
      }
    });
    function onClickCancel() {
      emit('click:cancel');
    }
    function onClickSave() {
      emit('click:save');
      emit('update:modelValue', selected.value);
    }
    useRender(() => {
      const [pickerProps] = VPicker.filterProps(props);
      const [datePickerHeaderProps] = VDatePickerHeader.filterProps(props);
      const [datePickerControlsProps] = VDatePickerControls.filterProps(props);
      const [datePickerMonthProps] = VDatePickerMonth.filterProps(props);
      const [datePickerYearsProps] = VDatePickerYears.filterProps(props);
      return _createVNode(VPicker, _mergeProps(pickerProps, {
        "class": ['v-date-picker', props.class],
        "style": props.style,
        "title": title.value
      }), {
        header: () => _createVNode(VDatePickerHeader, _mergeProps(datePickerHeaderProps, {
          "displayDate": displayDate.value,
          "onUpdate:displayDate": $event => displayDate.value = $event,
          "inputMode": inputMode.value,
          "onUpdate:inputMode": $event => inputMode.value = $event,
          "modelValue": selected.value
        }), null),
        default: () => inputMode.value === 'calendar' ? _createVNode(_Fragment, null, [_createVNode(VDatePickerControls, _mergeProps(datePickerControlsProps, {
          "displayDate": displayDate.value,
          "onUpdate:displayDate": $event => displayDate.value = $event,
          "viewMode": viewMode.value,
          "onUpdate:viewMode": $event => viewMode.value = $event
        }), null), _createVNode(MaybeTransition, {
          "transition": props.transition,
          "mode": "out-in"
        }, {
          default: () => [viewMode.value === 'month' ? _createVNode(VDatePickerMonth, _mergeProps(datePickerMonthProps, {
            "modelValue": selected.value,
            "onUpdate:modelValue": $event => selected.value = $event,
            "displayDate": displayDate.value,
            "onUpdate:displayDate": $event => displayDate.value = $event
          }), null) : _createVNode(VDatePickerYears, _mergeProps(datePickerYearsProps, {
            "displayDate": displayDate.value,
            "onUpdate:displayDate": $event => displayDate.value = $event,
            "viewMode": viewMode.value,
            "onUpdate:viewMode": $event => viewMode.value = $event,
            "height": "300"
          }), null)]
        })]) : _createVNode("div", {
          "class": "v-date-picker__input"
        }, [_createVNode(VTextField, {
          "modelValue": inputModel.value,
          "onUpdate:modelValue": $event => inputModel.value = $event,
          "label": t(props.inputText),
          "placeholder": "dd/mm/yyyy"
        }, null)]),
        actions: !props.hideActions ? () => _createVNode("div", null, [_createVNode(VBtn, {
          "variant": "text",
          "color": props.color,
          "onClick": onClickCancel,
          "text": t(props.cancelText)
        }, null), _createVNode(VBtn, {
          "variant": "text",
          "color": props.color,
          "onClick": onClickSave,
          "text": t(props.okText)
        }, null)]) : undefined
      });
    });
    return {};
  }
});
//# sourceMappingURL=VDatePicker.mjs.map