import { createVNode as _createVNode } from "vue";
// Styles
import "./VDatePickerHeader.css";

// Components
import { VBtn } from "../../components/VBtn/index.mjs"; // Composables
import { useLocale } from "../../composables/locale.mjs"; // Utilities
import { computed } from 'vue';
import { dateEmits, makeDateProps } from "../VDateInput/composables.mjs";
import { useDate } from "../date/index.mjs";
import { genericComponent, omit, propsFactory, useRender } from "../../util/index.mjs";
export const makeVDatePickerHeaderProps = propsFactory({
  color: String,
  title: String,
  header: String,
  keyboardIcon: {
    type: String,
    default: '$edit'
  },
  calendarIcon: {
    type: String,
    default: '$calendar'
  },
  showInputSwitch: Boolean,
  range: [Boolean, String],
  ...omit(makeDateProps(), ['displayDate', 'viewMode'])
}, 'VDatePickerHeader');
export const VDatePickerHeader = genericComponent()({
  name: 'VDatePickerHeader',
  props: makeVDatePickerHeaderProps(),
  emits: {
    ...omit(dateEmits, ['update:modelValue', 'update:viewMode', 'update:modelValue'])
  },
  setup(props, _ref) {
    let {
      emit
    } = _ref;
    const {
      t
    } = useLocale();
    const adapter = useDate();
    const headerText = computed(() => {
      if (props.header) return props.header;
      if (!props.modelValue?.length) return t(`$vuetify.datePicker.${props.range ? 'range.' : ''}header`);
      if (props.modelValue.length === 1) return adapter.format(props.modelValue[0], 'normalDateWithWeekday');
      return props.modelValue.map(date => adapter.format(date, 'monthAndDate')).join(' - ');
    });
    function handleHeaderClick() {
      if (!props.modelValue.length) return;
      const date = props.modelValue[0];
      emit('update:displayDate', date);
    }
    useRender(() => _createVNode("div", {
      "class": ['v-date-picker-header']
    }, [_createVNode("div", {
      "class": "v-date-picker-header__wrapper"
    }, [_createVNode("div", {
      "class": "v-date-picker-header__text"
    }, [_createVNode("div", {
      "class": "v-date-picker-header__date",
      "onClick": handleHeaderClick
    }, [headerText.value]), _createVNode(VBtn, {
      "variant": "text",
      "icon": props.inputMode === 'keyboard' ? props.calendarIcon : props.keyboardIcon,
      "onClick": () => emit('update:inputMode', props.inputMode === 'keyboard' ? 'calendar' : 'keyboard')
    }, null)])])]));
    return {};
  }
});
//# sourceMappingURL=VDatePickerHeader.mjs.map